summaryrefslogtreecommitdiffstats
path: root/configure.py
diff options
context:
space:
mode:
Diffstat (limited to 'configure.py')
-rw-r--r--configure.py80
1 files changed, 40 insertions, 40 deletions
diff --git a/configure.py b/configure.py
index dd251d2..9c9a388 100644
--- a/configure.py
+++ b/configure.py
@@ -96,8 +96,8 @@ opt_dep_warnings = 0
opt_libdir = "lib"
opt_dist_name = ""
-pytde_modules = ["dcop", "tdecore", "tdefx", "tdeui", "kio", "kresources", "kabc", "kutils", "kfile", "kparts",\
- "khtml", "kspell", "tdeprint", "kmdi"] #, "kspell2"]
+pytde_modules = ["dcop", "tdecore", "tdefx", "tdeui", "kio", "tderesources", "kabc", "tdeutils", "kfile", "tdeparts",\
+ "tdehtml", "tdespell", "tdeprint", "tdemdi"] #, "tdespell2"]
pytde_imports = {
"dcop": ["qt"],
@@ -106,16 +106,16 @@ pytde_imports = {
"tdefx": ["qt", "dcop", "tdecore"],
"tdeui": ["qt", "qtxml", "dcop", "tdecore", "tdefx"],
"kio": ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui"],
- "kresources": ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "kio"],
- "kabc": ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "kio", "kresources"],
- "kutils": ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "kio"],
+ "tderesources": ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "kio"],
+ "kabc": ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "kio", "tderesources"],
+ "tdeutils": ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "kio"],
"kfile": ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "kio"],
- "kparts": ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "kio"],
- "khtml": ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "kutils", "kio", "kparts"],
- "kspell": ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "kio", "kfile"],
+ "tdeparts": ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "kio"],
+ "tdehtml": ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "tdeutils", "kio", "tdeparts"],
+ "tdespell": ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "kio", "kfile"],
"tdeprint": ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui"],
- "kmdi": ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "kio", "kparts"],
- "kspell2": ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui"]
+ "tdemdi": ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui", "kio", "tdeparts"],
+ "tdespell2": ["qt", "qtxml", "dcop", "tdecore", "tdefx", "tdeui"]
}
kde_includes = {
@@ -125,16 +125,16 @@ kde_includes = {
"tdefx": None,
"tdeui": None,
"kio": ["kio"],
- "kresources": ["kio", "../kio", "kresources"],
- "kabc": ["kio", "../kio", "kresources", "kabc"],
+ "tderesources": ["kio", "../kio", "tderesources"],
+ "kabc": ["kio", "../kio", "tderesources", "kabc"],
"kfile": ["kio", "../kio"],
- "kparts": ["kio", "../kio", "kparts"],
- "khtml": ["kio", "../kio", "kparts", "dom"],
- "kspell": ["kio"],
+ "tdeparts": ["kio", "../kio", "tdeparts"],
+ "tdehtml": ["kio", "../kio", "tdeparts", "dom"],
+ "tdespell": ["kio"],
"tdeprint": ["tdeprint"],
- "kmdi": ["kmdi", "kio", "../kio", "kparts"],
- "kutils": ["kio", "../kio"] #,
-# "kspell2": None
+ "tdemdi": ["tdemdi", "kio", "../kio", "tdeparts"],
+ "tdeutils": ["kio", "../kio"] #,
+# "tdespell2": None
}
postProcess = {
@@ -145,17 +145,17 @@ postProcess = {
# "tdesu": None,
"tdefx": None,
"tdeui": None, #[["-p ", "tdeui", "-o", "shpix", "siptdeuiKSharedPixmap.cpp"]],
- "kresources": None,
+ "tderesources": None,
"kabc": None,
"kio": None,
"kfile": None,
- "kparts": None,
- "khtml": None,
- "kspell": None,
+ "tdeparts": None,
+ "tdehtml": None,
+ "tdespell": None,
"tdeprint": None,
- "kmdi": None,
- "kutils": None #,
-# "kspell2": None
+ "tdemdi": None,
+ "tdeutils": None #,
+# "tdespell2": None
}
opt_startModName = ""
@@ -474,7 +474,7 @@ def create_top_level (mname):
elif string.find (line, "@mark@") == 0:
for p in plus:
sipout.write (p)
- elif mname == "kabc" and kde_version < 0x030200 and string.find (line, "kresourcesmod.sip") >= 0:
+ elif mname == "kabc" and kde_version < 0x030200 and string.find (line, "tderesourcesmod.sip") >= 0:
pass
else:
sipout.write (line)
@@ -484,14 +484,14 @@ def create_top_level (mname):
sipin.close ()
sipout.close ()
- if mname == "khtml":
- # PyKDE < 3.3.0 doesn't provide kutils (and khtml doesn't need it)
+ if mname == "tdehtml":
+ # PyKDE < 3.3.0 doesn't provide tdeutils (and tdehtml doesn't need it)
sippath = srcPath(os.path.join ("sip", mname))
if kde_version < 0x030300:
sipin = open (os.path.join (sippath, mname + "mod.sip"))
sipout = open (os.path.join (sippath, mname + "mod.sip.new"), "w")
for line in sipin:
- if line.find ("kutilsmod.sip") > 0:
+ if line.find ("tdeutilsmod.sip") > 0:
continue
sipout.write (line)
sipin.close ()
@@ -499,10 +499,10 @@ def create_top_level (mname):
os.unlink (os.path.join (sippath, mname + "mod.sip"))
os.rename (os.path.join (sippath, mname + "mod.sip.new"), os.path.join (sippath, mname + "mod.sip"))
- os.system ("cp %s %s" % (os.path.join (sippath, "khtml_part.sip.323"), os.path.join (sippath, "khtml_part.sip")))
+ os.system ("cp %s %s" % (os.path.join (sippath, "tdehtml_part.sip.323"), os.path.join (sippath, "tdehtml_part.sip")))
else:
- os.system ("cp %s %s" % (os.path.join (sippath, "khtml_part.sip.330"), os.path.join (sippath, "khtml_part.sip")))
+ os.system ("cp %s %s" % (os.path.join (sippath, "tdehtml_part.sip.330"), os.path.join (sippath, "tdehtml_part.sip")))
def check_distribution ():
@@ -755,11 +755,11 @@ def generate_code(mname, imports=None, extra_cflags=None, extra_cxxflags=None, e
makefile.extra_libs.append(extra_lib)
if extra_lib == "tdefx":
makefile.extra_libs.append ("tdecore")
- if extra_lib == "kspell":
+ if extra_lib == "tdespell":
makefile.extra_libs.append ("tdeui")
if extra_lib == "kabc" and kde_version >= 0x030200:
makefile.extra_libs.append ("kabc_file")
- if extra_lib == "kparts" and kde_version >= 0x030500:
+ if extra_lib == "tdeparts" and kde_version >= 0x030500:
makefile.extra_lib_dirs.append (os.path.join (opt_kdelibdir, "trinity"))
if extra_lib == "tdeprint":
@@ -894,15 +894,15 @@ def main(argv):
# Set the SIP platform, version and feature flags.
if kde_version < 0x030200:
- pytde_modules.remove ("kmdi")
- pytde_modules.remove ("kresources")
- pytde_imports ["kabc"].remove ("kresources")
- kde_includes ["kabc"].remove ("kresources")
+ pytde_modules.remove ("tdemdi")
+ pytde_modules.remove ("tderesources")
+ pytde_imports ["kabc"].remove ("tderesources")
+ kde_includes ["kabc"].remove ("tderesources")
if kde_version < 0x030300:
- pytde_modules.remove ("kutils")
-# pytde_modules.remove ("kspell2")
- pytde_imports ["khtml"].remove ("kutils")
+ pytde_modules.remove ("tdeutils")
+# pytde_modules.remove ("tdespell2")
+ pytde_imports ["tdehtml"].remove ("tdeutils")
opt_endmod = len (pytde_modules)
if opt_startModName != "":